%define upstream_name  	    Devel-NYTProf
%define upstream_version 6.14

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3
Summary:    Powerful feature-rich perl source code profiler
Group:      Development/Perl
License:    Artistic
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Devel/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Capture::Tiny)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Which) >= 1.90.0
BuildRequires: perl(Getopt::Long)
BuildRequires: perl(JSON::MaybeXS)
BuildRequires: perl(List::Util)
BuildRequires: perl(Sub::Name) >= 0.110.0
BuildRequires: perl(Test::Differences) >= 0.600.0
BuildRequires: perl(Test::More) >= 0.840.0
BuildRequires: perl(XSLoader)
BuildRequires: perl-devel
%{?perl_default_filter}

%description
Devel::NYTProf is a powerful feature-rich perl source code profiler.

  * Performs per-line statement profiling for fine detail
  * Performs per-subroutine statement profiling for overview
  * Performs per-block statement profiling (the first profiler to do so)
  * Accounts correctly for time spent after calls return
  * Performs inclusive and exclusive timing of subroutines
  * Subroutine times are per calling location (a powerful feature)
  * Can profile compile-time activity, just run-time, or just END time
  * Uses novel techniques for efficient profiling
  * Sub-microsecond (100ns) resolution on systems with clock_gettime()
  * Very fast - the fastest statement and subroutine profilers for perl
  * Handles applications that fork, with no performance cost
  * Immune from noise caused by profiling overheads and I/O
  * Program being profiled can stop/start the profiler
  * Generates richly annotated and cross-linked html reports
  * Trivial to use with mod_perl - add one line to httpd.conf
  * Includes an extensive test suite
  * Tested on very large codebases

NYTProf is effectively two profilers in one: a statement profiler, and a
subroutine profiler.

%prep
%setup -q -n %{upstream_name}-%{upstream_version} 

%build
%__perl Makefile.PL INSTALLDIRS=vendor
%make_build CFLAGS="%optflags"

%check
make test

%install
%make_install

%files
%doc Changes HACKING INSTALL META.json META.yml MYMETA.yml demo
%{_bindir}/*
%{_mandir}/*/*
%{perl_vendorarch}/Devel
%{perl_vendorarch}/auto/*


%changelog
* Fri Aug 23 2024 tv <tv> 6.140.0-3.mga10
+ Revision: 2089310
- Rebuild for perl-5.40

* Fri Dec 01 2023 tv <tv> 6.140.0-2.mga10
+ Revision: 2012056
- Rebuild for perl-5.38

* Mon Oct 23 2023 tv <tv> 6.140.0-1.mga10
+ Revision: 2000319
- update to 6.14

* Tue Nov 22 2022 tv <tv> 6.120.0-1.mga9
+ Revision: 1910040
- update to 6.12

* Tue Jun 07 2022 umeabot <umeabot> 6.110.0-3.mga9
+ Revision: 1861783
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 6.110.0-2.mga9
+ Revision: 1796458
- Mageia 9 Mass Rebuild

* Mon Sep 20 2021 tv <tv> 6.110.0-1.mga9
+ Revision: 1746061
- update to 6.11

* Mon May 24 2021 umeabot <umeabot> 6.100.0-2.mga9
+ Revision: 1726554
- Rebuild for perl 5.34

* Tue May 18 2021 tv <tv> 6.100.0-1.mga9
+ Revision: 1725377
- update to 6.10

* Tue May 04 2021 tv <tv> 6.90.0-1.mga9
+ Revision: 1721286
- update to 6.09

* Thu Apr 29 2021 tv <tv> 6.80.0-1.mga9
+ Revision: 1720383
- update to 6.08

* Fri Apr 09 2021 tv <tv> 6.70.0-1.mga9
+ Revision: 1714218
- update to 6.07

* Wed Jun 17 2020 umeabot <umeabot> 6.60.0-6.mga8
+ Revision: 1594540
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 6.60.0-5.mga8
+ Revision: 1529445
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 tmb <tmb> 6.60.0-4.mga8
+ Revision: 1433516
- rebuild for perl 5.30

* Fri Sep 21 2018 umeabot <umeabot> 6.60.0-3.mga7
+ Revision: 1292787
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 6.60.0-2.mga7
+ Revision: 1250302
- Rebuild for perl 5.28

* Fri Jun 22 2018 shlomif <shlomif> 6.60.0-1.mga7
+ Revision: 1238923
- update to 6.06

* Mon Apr 09 2018 kekepower <kekepower> 6.50.0-1.mga7
+ Revision: 1216682
- Update to version 6.05

* Mon Oct 02 2017 tv <tv> 6.40.0-3.mga7
+ Revision: 1164063
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 6.40.0-2.mga7
+ Revision: 1149617
- Rebuild for perl ABI changes

* Mon Jul 24 2017 sander85 <sander85> 6.40.0-1.mga7
+ Revision: 1130021
- update to 6.04
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 6.30.0-2.mga6
+ Revision: 1025537
- Rebuild for perl 5.22.2

* Fri Apr 15 2016 shlomif <shlomif> 6.30.0-1.mga6
+ Revision: 1001835
- update to 6.03

* Fri Feb 12 2016 umeabot <umeabot> 6.20.0-2.mga6
+ Revision: 957167
- Mageia 6 Mass Rebuild

* Wed Aug 05 2015 sander85 <sander85> 6.20.0-1.mga6
+ Revision: 861316
- update to 6.02

* Fri Jun 26 2015 tv <tv> 6.10.0-2.mga6
+ Revision: 844860
- rebuild for soname-ifed perl

* Tue Jun 23 2015 tv <tv> 6.10.0-1.mga6
+ Revision: 841267
- new release
- rebuild for perl-5.22

* Wed Oct 15 2014 umeabot <umeabot> 5.60.0-6.mga5
+ Revision: 742725
- Second Mageia 5 Mass Rebuild

* Thu Oct 02 2014 tv <tv> 5.60.0-5.mga5
+ Revision: 735577
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 5.60.0-4.mga5
+ Revision: 684323
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 5.60.0-3.mga5
+ Revision: 631061
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 5.60.0-2.mga4
+ Revision: 534777
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 sander85 <sander85> 5.60.0-1.mga4
+ Revision: 478826
- update to 5.06

* Wed Jun 26 2013 jquelin <jquelin> 5.40.0-1.mga4
+ Revision: 446938
- update to 5.04

* Wed May 29 2013 jquelin <jquelin> 5.30.0-1.mga4
+ Revision: 431681
- update to 5.03
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 4.230.0-2.mga3
+ Revision: 365789
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 jquelin <jquelin> 4.230.0-1.mga3
+ Revision: 342079
- update to 4.23

* Mon Sep 17 2012 jquelin <jquelin> 4.90.0-1.mga3
+ Revision: 295000
- update to 4.09

* Fri Aug 31 2012 kharec <kharec> 4.80.0-1.mga3
+ Revision: 286068
- update to 4.08

* Wed May 30 2012 jquelin <jquelin> 4.60.0-3.mga3
+ Revision: 250524
- rebuild for perl 5.16

* Sat Jun 11 2011 sander85 <sander85> 4.60.0-2.mga2
+ Revision: 104178
- perl 5.14

* Fri Jan 21 2011 jquelin <jquelin> 4.60.0-1.mga1
+ Revision: 30133
- mageia rebuild
- imported package perl-Devel-NYTProf

